﻿using System.Collections.Generic;
using System.Windows;
using System.Windows.Media;

namespace WpfView
{
  /// <summary>
  /// Utility for navigating on the visual tree
  /// </summary>
  internal static class VisualElementHelper
  {
    internal static IEnumerable<T> FindVisualChildren<T>(DependencyObject depObj)
      where T : DependencyObject
    {
      if (depObj != null)
      {
        for (int i = 0; i < VisualTreeHelper.GetChildrenCount(depObj); i++)
        {
          DependencyObject child = VisualTreeHelper.GetChild(depObj, i);
          if (child != null && child is T)
          {
            yield return (T)child;
          }

          foreach (T childOfChild in FindVisualChildren<T>(child))
          {
            yield return childOfChild;
          }
        }
      }
    }

    internal static T FindVisualParent<T>(UIElement element)
      where T : UIElement
    {
      UIElement parent = element;
      while (parent != null)
      {
        T correctlyTyped = parent as T;
        if (correctlyTyped != null)
        {
          return correctlyTyped;
        }
        parent = VisualTreeHelper.GetParent(parent) as UIElement;
      }
      return null;
    }
  }
}
